'
' USB HID Mouse descriptor module
'
' Do not change the order of the commands and directives
'
' Place any $defines here. i.e. before the loading of USB_MemAlloc.inc
' See USB_Defs.inc for the defines used
'
'$define USB_VID                 $04D8       ' User VID value
'$define USB_PID                 $0000       ' User PID value
$define USB_VID                 6017         ' User VID value
$define USB_PID                 2001        ' User PID value
$define HID_BUFFER_SIZE         32          ' USB Buffer Size.
$define USB_BUS_POWER           50          ' Bus power (50 to 250 milliAmps) x2

$define USB_SERVICE                         ' Use the Timer1 low priority interrupt for enumeration and bus servicing
$define USB_USE_HID                         ' Indicate we require to use a HID interface
$define USB_CONNECT_LED PORTC.3             ' This pin goes high when the USB is in a connected state
$define USB_SELF_POWER                      ' Indicate that the PICmicro is self powered. i.e. Not powered by the bus
$define HID_EP_OUT_POLLING_MS   1           ' HID - EP01 - 1ms (EP01Out)
$define HID_EP_IN_POLLING_MS    1           ' HID - EP01 - 1ms (EP01In)

$define HID_INTF_ID             $00
$define HID_EP                  1           ' Endpoint number
$define HID_INT_OUT_EP_SIZE     3
$define HID_INT_IN_EP_SIZE      3
$define HID_NUM_OF_DSC          1           ' Number of descriptors

$define HID_RPT01_SIZE          50          ' Size of "hid_rpt01" table (in bytes)
'
'---------------------------------------------------------------------------------------------------------
'
    Include "USB_MemAlloc.inc"              ' ** Load the USB Stack and Dual Port RAM variable definitions **
'
'---------------------------------------------------------------------------------------------------------
'
    GoTo OverDescriptorTables               ' Jump over the descriptor tables
'
'---------------------------------------------------------------------------------------------------------
'

'
' This section may be modified to suit your requirements
' Do not change any of the label names, or the format of the tables
'
device_dsc:
    CData   $12,_                           ' Size of this descriptor in bytes
            USB_DESCRIPTOR_DEVICE,_         ' Device descriptor type
            $02, 00,_                       ' USB Spec Release Number in BCD format (low byte, high byte)
            $00,_                           ' Class Code
            $00,_                           ' Subclass code
            $00,_                           ' Protocol code
            USB_EP0_BUFF_SIZE,_             ' Max packet size For EP0
            USB_VID & $FF, USB_VID >> 8,_   ' Vendor ID (low byte, byte byte)
            USB_PID & $FF, USB_PID >> 8,_   ' Product ID (low byte, high byte)
            $00, $03,_                      ' Device release number in BCD format (low byte, high byte)
            $01,_                           ' Manufacturer String index
            $02,_                           ' Product String index
            $00,_                           ' Device serial number String index
            $01                             ' Number of possible configurations
'
' Configuration Descriptor
'
configDescriptor1:
    CData   $09,_                           ' Size of this section of the descriptor (in bytes)
            USB_DESCRIPTOR_CONFIGURATION,_  ' Configuration descriptor type
            SizeOf_Table, $00,_             ' Size Of "configDescriptor1" table - Total length of data (low byte, high byte)
            $01,_                           ' Number of interfaces in this configuration
            $01,_                           ' Index value of this configuration
            $00,_                           ' Configuration string index
            _DEFAULT | _SELF,_              ' Attributes, see USB_defs.inc
            USB_BUS_POWER,_                 ' Max power consumption (2X mA)
            '
            ' Interface descriptor
            '
            $09,_                           ' Size of this section of the descriptor (in bytes)
            USB_DESCRIPTOR_INTERFACE,_      ' Interface descriptor type
            $00,_                           ' Interface Number
            $00,_                           ' Alternate Setting Number
            $01,_                           ' Number of endpoints in this intf
            HID_INTF,_                      ' Class code
            $01,_                           ' Subclass code
            HID_PROTOCOL_MOUSE,_            ' Protocol code
            $00,_                           ' Interface string index
            '
            ' HID class-specific descriptor
            '
            $09,_                           ' Size of this section of the descriptor (in bytes)
            DSC_HID,_                       ' HID descriptor type
            $11, $01,_                      ' HID Spec Release Number in BCD format (low byte, high byte)
            $00,_                           ' Country Code (00 for Not supported)
            HID_NUM_OF_DSC,_                ' Number of class descriptors, see USB_cfg.inc
            DSC_RPT,_                       ' Report descriptor type
            HID_RPT01_SIZE, $00,_           ' Size of "hid_rpt01" table (low byte, high byte)
            '
            ' Endpoint descriptor (IN)
            '
            $07,_                           ' Size of this section of the descriptor (in bytes)
            USB_DESCRIPTOR_ENDPOINT,_       ' Endpoint descriptor type
            HID_EP | _EP_IN,_               ' Endpoint 1 in
            _INTERRUPT,_                    ' Interrupt transfers
            HID_INT_IN_EP_SIZE, $00,_       ' Maximum packet size (low byte, high byte)
            HID_EP_IN_POLLING_MS            ' Polling interval (in milliseconds)
'
' Language string - unicode format
'
sd000:
    CData   Byte SizeOf_Table,_             ' Size of this descriptor in bytes
            Byte USB_DESCRIPTOR_STRING,_    ' Descriptor Type
            Word $0904                      ' language ID - (high byte, low byte)
'
' Manufacturer string - unicode format
'
sd001:
    CData   Byte SizeOf_Table,_
            Byte USB_DESCRIPTOR_STRING,_
            Word "Crownhill"
'
' Product string - unicode format
'
sd002:
    CData   Byte SizeOf_Table,_
            Byte USB_DESCRIPTOR_STRING,_
            Word "Proton - HID Mouse"

$ifdef USB_HAVE_SERIAL_STRING
sd003:
    CData   Byte SizeOf_Table,_             ' Size of this descriptor (in bytes)
            Byte USB_DESCRIPTOR_STRING,_
            Word "1234567"                  ' Serial string - unicode format
$endif
'
' This example report descriptor for a generic HID mouse defines one report of each type.
' Each report contains two bytes of data with a vendor-defined Usage.
'
hid_rpt01:
    CData   $05, $01,_                      ' Usage Page (Generic Desktop)
            $09, $02,_                      ' Usage (Mouse)
            $A1, $01,_                      ' Collection (Application)
            $09, $01,_                      ' Usage (Pointer)
            $A1, $00,_                      ' Collection (Physical)
            $05, $09,_                      ' Usage Page (Buttons)
            $19, $01,_                      ' Usage Minimum (01)
            $29, $03,_                      ' Usage Maximum (03)
            $15, $00,_                      ' Logical Minimum (0)
            $25, $01,_                      ' Logical Maximum (0)
            $95, $03,_                      ' Report Count (3)
            $75, $01,_                      ' Report Size (1)
            $81, $02,_                      ' Input (Data, Variable, Absolute)
            $95, $01,_                      ' Report Count (1)
            $75, $05,_                      ' Report Size (5)
            $81, $01,_                      ' Input (Constant) - 5 bit padding
            $05, $01,_                      ' Usage Page (Generic Desktop)
            $09, $30,_                      ' Usage (X)
            $09, $31,_                      ' Usage (Y)
            $15, $81,_                      ' Logical Minimum (-127)
            $25, $7F,_                      ' Logical Maximum (127)
            $75, $08,_                      ' Report Size (8)
            $95, $02,_                      ' Report Count (2)
            $81, $06,_                      ' Input (Data, Variable, Relative)
            $C0, $C0
'
'---------------------------------------------------------------------------------------------------------
'
USB_CD_Pointer:
    CData configDescriptor1, configDescriptor1   ' Create a pointer to the descriptor's configDescriptor1 table

USB_SD_Pointer:
$ifdef USB_HAVE_SERIAL_STRING
    CData sd000, sd001, sd002, sd003    ' Create a pointer to the descriptor's sd tables(with serial)
$else
    CData sd000, sd001, sd002           ' Create a pointer to the descriptor's sd tables (without serial)
$endif

OverDescriptorTables:
    Include "USB_System.inc"            ' ** Load the USB routines into the program **

$ifdef USB_USE_HID
    Include "USB_UserHID.inc"           ' ** Load the User HID routines into the program (if a HID interface is being used)
$endif

